--  Copyright (c) 2007 Solomon Peachy (pizza@shaftnet.org)

--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 3 of the License, or
--  (at your option) any later version.

--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.

--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

----------------------------------------------------------
-- v2.37.A to 2.37.B patch 
----------------------------------------------------------

---- More efficient way to get random photos.

CREATE OR REPLACE FUNCTION get_random_photos(integer, integer, character varying[], integer) RETURNS SETOF integer AS '
DECLARE num_rows alias for $1;
	viewer_id alias for $2;
	passwd_list alias for $3;
	user_id alias for $4;
	xmax INT;
	pick INT;
	matchid INT;
	safety INT = 0;
	rows INT = 0;
BEGIN 
      select last_value from photo_id_sequence into xmax;
      LOOP
	    EXIT WHEN rows >= num_rows;

            SELECT CEIL(xmax * RANDOM()) INTO pick;
	    IF user_id > 0 THEN
	    	    SELECT identifier FROM photo where identifier = pick and users = user_id and can_access_photo(identifier, viewer_id, passwd_list) INTO matchid;
            ELSE
	    	    SELECT identifier FROM photo where identifier = pick and can_access_photo(identifier, viewer_id, passwd_list) INTO matchid;
	    END IF;
	    IF matchid IS NOT NULL THEN
	       rows = rows + 1;
	       RETURN NEXT matchid; 
            END IF;

	    safety = safety + 1;	
	    EXIT WHEN safety > 10000;
      END LOOP;
      RETURN;
END;
' 
LANGUAGE plpgsql;

-----  TO deal with imports

CREATE SEQUENCE pending_imports_sequence START 1;

CREATE TABLE pending_imports (
       identifier integer NOT NULL PRIMARY KEY,
       users integer references users(identifier) NOT NULL,
       folder integer references folder(identifier),
       photo_data TEXT
);

CREATE SEQUENCE import_results_sequence START 1;

CREATE TABLE import_results (
       identifier integer NOT NULL PRIMARY KEY DEFAULT nextval('import_results_sequence'),
       users integer references users(identifier) NOT NULL,
       log_data TEXT
);

----  Speed up some queries

create index photo_exposure_date_idx on photo(date_of_exposure);
create index photo_version_creation_date_idx on photo_version(date_of_creation);

----  Re-add default sort order to folders & albums

ALTER TABLE folder add column "orderby" integer;
ALTER TABLE album add column "orderby" integer;

-- version update 
update version set identifier=3, description='2.37 Development release', 
 major=2, minor=37, variation='B';
